const consola = require("consola");
const { exec } = require("child_process");
const shell = require("shelljs");
const ncp = require("ncp");

async function publishToNpm(srcFolder, destFolder, configPath) {
  try {
    shell.rm("-R", destFolder);
    shell.mkdir(destFolder);
    await copyContents(srcFolder, destFolder);
    await copyConfig(configPath, destFolder);
    const config = require(configPath);
    await publish(config, destFolder);
  } catch (err) {
    consola.error(err);
  } finally {
    shell.rm("-R", destFolder);
  }
}

async function copyContents(src, dest) {
  shell.cp(`-R`, src, dest);
}

function copyConfig(src, dest) {
  return new Promise((resolve, reject) => {
    ncp(src, `${dest}/package.json`, (err) => {
      if (err) reject(err);
      consola.success("Copied package config");
      resolve();
    });
  });
}

function publish(config, destFolder) {
  consola.info(`Publishing ${config.name}`);
  return new Promise((resolve, reject) => {
    const ls = exec(
      `npm publish ${destFolder}`,
      function (error, stdout, stderr) {
        if (error) {
          reject(error);
        }
        consola.info("Child Process STDOUT: " + stdout);
        consola.warn("Child Process STDERR: " + stderr);
      }
    );

    ls.on("exit", function (code) {
      consola.success(
        `Published ${config.name} @ https://www.npmjs.com/package/${config.name}`
      );
      resolve();
    });
  });
}

module.exports = publishToNpm;
