const fs = require("fs");
const path = require("path");
const glob = require("glob");
const consola = require("consola");
const config = require("../config");
const publishToNpm = require("../utils/publishToNpm");
const fireProcess = require("../utils/fireProcess");
const shell = require("shelljs");

const targetGlob = `./src/components/**/*.scss`;
const tempComponentsFolder = path.normalize(
  path.resolve(config.paths.temp, "./components")
);

if (!fs.existsSync(config.paths.temp))
  fs.mkdirSync(config.paths.temp, { recursive: true });
if (!fs.existsSync(tempComponentsFolder)) fs.mkdirSync(tempComponentsFolder);

glob(targetGlob, async (err, matches) => {
  matches.forEach((file) => {
    const fileName = path.basename(file);
    const dest = path.normalize(
      path.resolve(tempComponentsFolder, `./${fileName}`)
    );
    fs.copyFileSync(file, dest);
  });

  await fireProcess(
    `cd ${config.paths.workflow} && node preprocessStyles.js --dest=${tempComponentsFolder}`,
    true,
    true,
    true
  );

  const destFolder = path.resolve(
    __dirname,
    `../npm-package-${new Date().getTime()}`
  );

  const pathPackageConfig = path.resolve(
    __dirname,
    "./npmPublishConfigurations/scss.package.json"
  );

  const srcFolder = path.resolve(config.paths.temp, "./components");

  try {
    publishToNpm(srcFolder, destFolder, pathPackageConfig);
  } catch (error) {
    consola.error(error);
  } finally {
    shell.rm("-R", config.paths.temp);
  }
});
